BBC - Homepage
Description: Breaking news, sport, TV, radio and a whole lot more. The BBC informs, educates and entertains - wherever you are, whatever your age.
Keywords: BBC, bbc.co.uk, bbc.com, Search, British Broadcasting Corporation, BBC iPlayer, BBCi

British Broadcasting Corporation Home

Accessibility links

- Skip to content
- Skip to bbc.co.uk navigation
- Skip to bbc.co.uk search
- Help
- Accessibility Help

# BBC Homepage

## Top stories »

Drugs 'reduce' HIV transmission
  An HIV positive person can reduce the risk of spreading the virus to uninfected partners by 96% if they are given anti-retroviral drugs immediately, according to US scientists.

Uefa charges Busquets over racism
  Uefa launches a disciplinary case against Barcelona's Sergio Busquets over alleged racial abuse in the Champions League tie with Real Madrid.

Back to the future of St Petersburg
  Hotels, restaurants and museums that highlight two different cities, one new and the other historic, both splendid.

## News »

### Top Story

Fears for Bin Laden US Navy Seals

US Defence Secretary Robert Gates says security around the special forces unit that killed Osama Bin Laden will be tightened after it raised concerns.

Nato in new raid on Gaddafi base

Nato air strikes again target Col Muammar Gaddafi's compound, hours after Libyan state TV showed footage purportedly of the leader in Tripoli.

- Syria 'to halt firing on rallies'
- Facebook exposed in Google smear
- Demjanjuk guilty of Nazi murders
- Bernanke warns on US debt impasse
- Obama seeks new term for FBI head

## Business »

### Top Business and Money Stories

- Bernanke warns on US debt impasse
- Egypt asks IMF to prop up deficit

### Market Data Thu, 12 May 2011 21:59 BST

#### Marketwatch

(min delay 15 mins) Marketwatch Ticker

Market Name | Current Value | Movement | Change | Percentage Change
--- | --- | --- | --- | ---
Dow Jones | 12695.92 | + | 65.89 | 0.52%
Nasdaq | 2863.04 | + | 17.98 | 0.63%
FTSE 100 | 5944.96 | - | -31.04 | -0.52%
Dax | 7443.95 | - | -51.1 | -0.68%
Cac 40 | 4023.29 | - | -34.79 | -0.86%

## Sport »

Woods out of Players Championship

Tiger Woods pulls out of the Players Championship midway through his first round with a recurrence of his knee and Achilles tendon injuries.

- Dalglish given new Liverpool deal
- Federer beaten by Gasquet in Rome
- Blanc backed in France race row
- Nott'm Forest 0-0 Swansea

## Entertainment & Arts »

In Association With

### Top Story

Cannes gets talking about Kevin

Critics heap praise on We Need to Talk about Kevin, the only British title in contention for the main award at the Cannes Film Festival.

- Warhol self-portrait gets $38.4m
- Michael announces orchestral tour

- Lindsay Lohan sentenced to jail
- Radio listening reaches new high
- Eurovision hopefuls whittled down
- Classic Brits 'may honour shows'
- King's Speech wins trio of awards
- Burgess archive yields lost gems
- Warhol's Jackies scrapes $20m tag

## Health »

### Top Story

Drugs 'reduce' HIV transmission

An HIV positive person can reduce the risk of spreading the virus to uninfected partners by 96% if they are given anti-retroviral drugs immediately, according to US scientists.

- Monkey HIV vaccine 'effective'
- Selenium 'does not stop cancer'

- Rise in number of 'legal highs'
- Coffee a breast cancer preventer?
- Dengue fever cases 'double in UK'
- Children 'recall early memories'
- Breastfeeding 'helps behaviour'
- Gay men 'have higher cancer rate'
- Face transplant man 'can smell'

## Technology »

### Top Story

Facebook exposed in Google smear

Facebook admits hiring a PR agency to tout anti-Google stories related to user privacy in the US press.

- Wiki boss criticises injunctions
- Twitpic triggers copyright clash

- Digital music sales 'pass £1bn'
- Google unveils Chrome laptops
- Facebook profile access 'leaked'
- ACS:Law fined over data breach
- Apple, Google in privacy hearing
- 100,000 net champions recruited
- Google Music stumbles at launch

## Science & Environment »

### Top Story

Jupiter moon 'holds magma ocean'

Data from the Galileo probe suggest Jupiter's moon Io may hold a giant magma ocean beneath its crust that is at least 50km thick.

- Resource demand threatens future
- Setbacks at Japan nuclear plant

- Private route to fisheries reform
- Wikileaks shows Arctic 'carve up'
- Drug ban helps vulture recovery
- Monkey HIV vaccine 'effective'
- UK leads space disaster charter
- Brazil forest law vote postponed
- Arctic states meet in Greenland

## Travel »

In Association With

Mini guide to San Francisco
  Even if San Francisco’s streets are not paved with gold, they are splashed with rainbow-coloured murals and the skies over North Beach are ruled by trash-talking parrots.

Going around the world with kids
  How to prepare if you are thinking of packing up and travelling with kids for a couple of years.

A vintage car rally through Italy
  The Mille Miglia sees classic cars set off from Brescia on 12 May, then thunder through tranquil Italian villages down to Rome.

Barcelona: More than meets the eye
  Garish, gregarious Barcelona doesn’t guard its secrets jealously, but the Catalan capital does seem to get a kick from hiding the best of them in plain sight.

The rebirth of Detroit
  As the city continues the fight of its life, artists and visionaries are breathing life into tragic symbols of abandonment and decay.

Mexico City’s forgotten cantinas
  A cleaner and safer city centre has given 100-year-old bars a new lease on life.

Unequal travellers’ rights
  New passenger rights and regulations in the EU and US better protect airline passengers, but governmental intervention is less consistent elsewhere.

## World Service »

### Spanish

Tras el terremoto, centenares de inmigrantes deambulan por Lorca

Cerca del 20% de la población son inmigrantes, la mayoría de ellos ecuatorianos que han llegado en los últimos diez años. Muchos de ellos duermen en la calle tras la tragedia del miércoles.

### Chinese

研究：艾滋病毒传播风险可减96%

一项突破性研究发现，身体健康的艾滋病毒携带者在发现感染后立即服用抗逆转录病毒药，可将病毒传染给不带病毒的性伙伴的风险减少96%

### Arabic

زعيم معارض: القذافي "هدف مشروع" لغارات الناتو

رئيس المجلس الوطني الانتقالي الليبي المعارض يقول ان القذافي "هدف مشروع" لغارات حلف الناتو، الذي يواصل شن ضرباته على اهداف تابعة للحكومة الليبية.

### Persian

نویسنده نامه زندان رجایی شهر به انفرادی افتاد

مهدی محمودیان روزنامه‌نگاری که نامه‌ای در باره وقوع تجاورز جنسی در زندان رجایی شهر کرج منتشر کرده بود، به سلول انفرادی منتقل شده است.

### More languages

- Bangla
- Burmese
- French
- Hausa
- Hindi
- Indonesian
- Kinyarwanda
- Kirundi
- Kyrgyz
- Nepali
- Pashto
- Portuguese
- Russian
- Sinhala
- Somali
- Swahili
- Tamil
- Turkish
- Ukrainian
- Urdu
- Uzbek
- Vietnamese

## Spotlight

### Video and Audio

In Association With

### Top Story

The Queen passes a royal milestone

Queen Elizabeth II has become the second longest-serving monarch in British history, after 57 years and 97 days on the throne.

- Spanish earthquake aftermath
- Josie Foster stands by Mel Gibson
- One-minute World News

## Most Popular in News

### Shared

- 1: Facebook exposed in Google smear
- 2: Demjanjuk guilty of Nazi murders
- 3: Spain shocked by fatal earthquake
- 4: Monkey HIV vaccine 'effective'
- 5: Deadly quake rocks southern Spain

### Read

- 1: Fears for Bin Laden US Navy Seals
- 2: Facebook exposed in Google smear
- 3: Drugs 'reduce' HIV transmission
- 4: Demjanjuk guilty of Nazi murders
- 5: Day in pictures

### Watched/Listened

- 1: Jodie Foster stands by Mel Gibson
- 2: Queen Elizabeth II passes milestone
- 3: Footage shows Mount Etna eruption
- 4: Sobibor relative on Nazi verdict
- 5: Schoolboy wears a skirt to school

Functionality In Association With

## Weather »

In Association With

### London

Enter city, town or region

Friday

  Sunny Intervals

  Max Temperature: 18°C 64°F

  Min Temperature: 10°C 50°F

Saturday

  Sunny Intervals

  Max Temperature: 16°C 61°F

  Min Temperature: 8°C 46°F

Sunday

  White Cloud

  Max Temperature: 13°C 55°F

  Min Temperature: 10°C 50°F

Monday

  White Cloud

  Max Temperature: 15°C 59°F

  Min Temperature: 11°C 52°F

Detailed forecast

## Explore the BBC

### News

#### World Regions

- Africa
- Asia-Pacific
- Europe
- Latin America
- Middle East
- South Asia
- UK
- US & Canada

#### Types of news

- Business
- Health
- Science & Environment
- Technology
- Entertainment & Arts
- Also in the News

- BBC in your language

### Sport

- Football
- Cricket
- Tennis
- Motorsport

### Business

- Market Data
- Economy
- Companies

### Weather

- Weather News

### Travel

### Entertainment

- Entertainment News
- Comedy
- Drama

### Music

- Genres
- Reviews
- Artists
- News

### Arts & Culture

- Film

### Food

- Techniques
- Recipes

### Science

- Humans
- Space

### Nature

- Animals

### Gardening

- Plant finder
- Advice

### Religion

- Multifaith Calendar
- Quizzes

### Ethics

### Learning English

- Online courses
- Vocabulary & Grammar
- Quizzes

### Learning Other Languages

- French
- Spanish
- German
- Italian

### TV Channels

- BBC World News
- BBC America

### Radio

- World Service

Can't find it? Try the A to Z

## BBC links

- About the BBC
- BBC Help
- Contact Us
- Accessibility Help
- Terms of Use
- Jobs
- Privacy & Cookies
- Advertise With Us

BBC © 2011 The BBC is not responsible for the content of external sites. Read more.

This page is best viewed in an up-to-date web browser with style sheets (CSS) enabled. While you will be able to view the content of this page in your current browser, you will not be able to get the full visual experience. Please consider upgrading your browser software or enabling style sheets (CSS) if you are able to do so.